@@ -1,17 +1,16 @@
-# This file is part of Optcom.
+# Copyright 2019 The Optcom Authors
 #
-# Optcom is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-# Optcom is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
-# You should have received a copy of the GNU General Public License
-# along with Optcom.  If not, see <https://www.gnu.org/licenses/>.
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 """.. moduleauthor:: Sacha Medaer"""
 
@@ -373,7 +372,7 @@ if __name__ == "__main__":
                      INTRA_COMP_DELAY=True, INTRA_PORT_DELAY=False,
                      INTER_PORT_DELAY=False, noise_ode_method='rk1',
                      NOISE=True)
-    lt.link((pulse[0], fiber[0]))
+    lt.add_link(pulse[0], fiber[0])
     lt.run(pulse)
 
     x_datas: List[np.ndarray] = [pulse[0][0].nu, fiber[1][0].nu,
