@@ -1,17 +1,16 @@
-# This file is part of Optcom.
+# Copyright 2019 The Optcom Authors
 #
-# Optcom is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-# Optcom is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
-# You should have received a copy of the GNU General Public License
-# along with Optcom.  If not, see <https://www.gnu.org/licenses/>.
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 """.. moduleauthor:: Sacha Medaer"""
 
@@ -423,7 +422,7 @@ if __name__ == "__main__":
     or_p: float = 1e0
     lambdas_s: List[float] = [1030.0, 1020.0, 1025.0, 1015., 1010., 1100.]
     fwhm_s: List[float] =  [1.0 for i in range(nbr_ch_s)]
-    peak_power_s: List[float] = [3.0, 2.0, 1.0, 0.5, 0.3, 0.1]
+    peak_power_s: List[float] = [7.0, 2.0, 1.0, 0.5, 0.3, 0.1]
     rep_freq = [20e-6]   # THz
     pulse: oc.Gaussian = oc.Gaussian(channels=nbr_ch_s,
                                      peak_power=peak_power_s,
@@ -435,29 +434,26 @@ if __name__ == "__main__":
     pump: oc.CW = oc.CW(channels=nbr_ch_p, peak_power=peak_power_p,
                         center_lambda=lambdas_p)
 
-    steps: int = 200
+    steps: int = 100
     length: float = 0.002   # km
 
-    file_sigma_a: str = './data/fiber_amp/cross_section/absorption/yb.txt'
-    # emission max at 1024 nm
-    file_sigma_e: str = './data/fiber_amp/cross_section/emission/yb.txt'
-    sigma_a: List[Union[float, Callable, None]]
-    sigma_e: List[Union[float, Callable, None]]
-    sigma_a = [oc.CSVFit(file_sigma_a, conv_factor=[1e9, 1e18],
-                         conv_func=[oc.Domain.lambda_to_omega])]
-    sigma_e = [oc.CSVFit(file_sigma_e, conv_factor=[1e9, 1e18],
-                         conv_func=[oc.Domain.lambda_to_omega])]
-    n_core: List[Union[float, Callable, None]] = [None]
-    n_clad: List[Union[float, Callable, None]] = [None]
-    NA: List[Union[float, Callable, None]] = [0.11]
+    # Values taken partially from:
+    # https://www.osapublishing.org/oe/abstract.cfm?uri=oe-15-6-3236
+    sigma_a_s: float = 6.4e-9   # nm^{2}
+    sigma_a_p: float = 2.5e-6   # nm^{2}
+    sigma_a: List[Union[float, Callable, None]] = [sigma_a_s, sigma_a_p]
+    sigma_e_s: float = 3.2e-7   # nm^{2}
+    sigma_e_p: float = 2.5e-6   # nm^{2}
+    sigma_e: List[Union[float, Callable, None]] = [sigma_e_s, sigma_e_p]
+    NA: List[Union[float, Callable, None]] = [0.06]
     r_core: float = 6.0 / 2.0   # um
     r_clad: float = 125.0 / 2.0  # um
     temperature: float = 293.15    # K
     tau: float = 840.0    # us
-    N_T: float = 2.5e-2    # nm^{-3}
-    eta_s: float = 1.26     # km^-1
-    eta_p: float = 1.41     # km^-1
-    alpha: List[Union[List[float], Callable, None]] = [[eta_s], [eta_p]]
+    N_T: float = 4.6e-2    # nm^{-3}
+    alpha_s: float = 2.0     # km^-1
+    alpha_p: float = 0.4     # km^-1
+    alpha: List[Union[List[float], Callable, None]] = [[alpha_s], [alpha_p]]
     R_0: float = 8e-4
     R_L: float = R_0
     medium_core: str = 'sio2'
@@ -465,14 +461,13 @@ if __name__ == "__main__":
     max_nbr_iter: int = 10
     fiber: oc.FiberYb
     fiber = oc.FiberYb(length=length, nlse_method="rk4ip",
-                        alpha=alpha, beta_order = 2, alpha_order = 0,
+                        alpha=alpha, beta_order=2, alpha_order=0,
                         gain_order=0, GAIN_SAT=True,
                         nl_approx=False, ATT=[True, True], DISP=[True, False],
                         SPM=[True, False], XPM=[True, False], SS=[True, False],
                         RS=[True, False], XNL=[False, False],
                         approx_type=1, split_noise_option='seed_split',
-                        sigma_e=sigma_e, sigma_a=sigma_a,
-                        n_core=n_core, n_clad=n_clad, NA=NA,
+                        sigma_a=sigma_a, sigma_e=sigma_e, NA=NA,
                         core_radius=r_core, clad_radius=r_clad,
                         temperature=temperature, tau=tau,
                         N_T=N_T, R_0=R_0, R_L=R_L,
@@ -486,7 +481,7 @@ if __name__ == "__main__":
                         max_nbr_iter=max_nbr_iter, PROP_REFL=False,
                         PRE_PUMP_PROP=False, RESO_INDEX=True)
 
-    lt.link((pulse[0], fiber[0]), (pump[0], fiber[2]))
+    lt.add_links((pulse[0], fiber[0]), (pump[0], fiber[2]))
     lt.run(pulse, pump)
 
     # Power vs time plotting -------------------------------------------
