@@ -1,17 +1,16 @@
-# This file is part of Optcom.
+# Copyright 2019 The Optcom Authors
 #
-# Optcom is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-# Optcom is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
-# You should have received a copy of the GNU General Public License
-# along with Optcom.  If not, see <https://www.gnu.org/licenses/>.
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 """.. moduleauthor:: Sacha Medaer"""
 
@@ -777,7 +776,7 @@ if __name__ == "__main__":
         fiber = Fiber(length=0.2, nlse_method=nlse_method, alpha=[0.5],
                       beta_order=3, gamma=4.0, nl_approx=False, SPM=True,
                       XPM=True, SS=True, RS=True, steps=steps, save=True)
-        lt.link((pulse[0], fiber[0]))
+        lt.add_link(pulse[0], fiber[0])
         lt.run(pulse)
         lt.reset()
         # Plot parameters and get waves
